package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: Dec 15, 2018
License: BSD-2-Clause
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Pref struct {
DataDir, HomeDir, Add string
List, Search Query
Version, Init bool
MaxEntries int
}
Pref object.
type Query struct {
Start, Last string
}
Query object
IsNotEmpty returns true if Query.Last contains data.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.