Documentation
¶
Index ¶
- Variables
- type Repo
- func (r *Repo) Add(path string, t time.Time)
- func (r *Repo) List(q pref.Query, cutLong bool) rated.Slice
- func (r *Repo) Load(datadir string)
- func (r *Repo) Save() error
- func (r *Repo) Search(ch ResourceChecker, q pref.Query) (*rated.Rated, error)
- func (r *Repo) Size() int
- func (r *Repo) Walk(root string)
- type ResourceChecker
Constants ¶
This section is empty.
Variables ¶
var ( // ErrNoResult - search has no result ErrNoResult = errors.New("no result") )
Functions ¶
This section is empty.
Types ¶
type Repo ¶
type Repo struct {
// contains filtered or unexported fields
}
Repo content is saved to the disk.
func (*Repo) Add ¶
Add path to repo. If the path is known, the repo data is updated, else a new entry will be created.
type ResourceChecker ¶
ResourceChecker returns true when a resource exists.
Click to show internal directories.
Click to hide internal directories.